@@ -1,7 +1,4 @@
-#!/usr/bin/env python
-
 from avocado import Test
-from avocado import main
 
 
 class ErrorTest(Test):
@@ -17,7 +14,3 @@ class ErrorTest(Test):
         This should end with ERROR.
         """
         raise Exception("This is a generic exception")
-
-
-if __name__ == "__main__":
-    main()
