@@ -73,18 +73,23 @@ class Runnable(unittest.TestCase):
     def test_runnable_command_args(self):
         runnable = nrunner.Runnable('noop', 'uri', 'arg1', 'arg2')
         actual_args = runnable.get_command_args()
-        exp_args = ['-k', 'noop', '-u', 'uri', '-a', 'arg1', '-a', 'arg2']
+        exp_args = ['-k', 'noop', '-u', 'uri', '-c', '{}', '-a', 'arg1',
+                    '-a', 'arg2']
         self.assertEqual(actual_args, exp_args)
 
     def test_get_dict(self):
         runnable = nrunner.Runnable('noop', '_uri_', 'arg1', 'arg2')
         self.assertEqual(runnable.get_dict(),
                          {'kind': 'noop', 'uri': '_uri_',
-                          'args': ('arg1', 'arg2')})
+                          'args': ('arg1', 'arg2'),
+                          'config': {}})
 
     def test_get_json(self):
         runnable = nrunner.Runnable('noop', '_uri_', 'arg1', 'arg2')
-        expected = '{"kind": "noop", "uri": "_uri_", "args": ["arg1", "arg2"]}'
+        expected = ('{"kind": "noop", '
+                    '"uri": "_uri_", '
+                    '"config": {}, '
+                    '"args": ["arg1", "arg2"]}')
         self.assertEqual(runnable.get_json(), expected)
 
     def test_runner_from_runnable_error(self):
@@ -252,13 +257,9 @@ class Runner(unittest.TestCase):
         runner_klass = runnable.pick_runner_class()
         runner = runner_klass(runnable)
         results = [status for status in runner.run()]
-        if sys.version_info < (3, 11):
-            case_name = 'unittest.case.TestCase'
-        else:
-            case_name = 'unittest.case.TestCase.fail'
         output1 = ('============================================================='
-                   '=========\nFAIL: fail (%s)'
-                   '\nFail immediately, with the given message.' % case_name)
+                   '=========\nFAIL: fail (unittest.case.TestCase)'
+                   '\nFail immediately, with the given message.')
         output2 = '\n\nFAILED (failures=1)\n'
         result = results[-1]
         self.assertEqual(result['status'], 'finished')
